@@ -37,8 +37,6 @@ def cast_int(x):
     return int(x)
 
 
-make_bytes = bytes
-
 dtype_from_string = {
     "float32": torch.float32,
     "float64": torch.float64,
@@ -116,6 +114,18 @@ def make_diagonal(tensor: torch.Tensor, tensor_ints: Tuple[int, ...], out_ints:
     return result
 
 
+def tensor_to_bytes(x: torch.Tensor):
+    return x.cpu().numpy().tobytes()
+
+
+def tensor_from_bytes(device_dtype, shape, bytes, count):
+    return (
+        torch.frombuffer(bytes, count=count, offset=0, dtype=dtype_from_string[device_dtype.dtype])
+        .reshape(shape)
+        .to(device=device_dtype.device)
+    )
+
+
 einsum = lambda tensors_and_axes, out_axes: torch.einsum(*itertools.chain(*tensors_and_axes), out_axes)
 
 print = print
