@@ -5,7 +5,6 @@ use crate::{
 use std::{
     collections::hash_map::Entry::{self, Vacant},
     iter::zip,
-    rc::Rc,
     sync::Arc,
 };
 
@@ -30,7 +29,7 @@ use crate::{
     unwrap,
     util::{
         filter_out_idx, filter_to_idx, intersection_all, inverse_permutation, is_unique,
-        unique_to_appearance, EinInt,
+        unique_to_appearance, AxisInt,
     },
 };
 
@@ -278,14 +277,14 @@ pub fn einsum_nest_path(einsum: &Einsum, path: Vec<Vec<usize>>) -> Einsum {
             if stack.is_empty() {
                 einsum.out_axes.clone()
             } else {
-                let outer_indices_set: HashSet<EinInt> = stack
+                let outer_indices_set: HashSet<AxisInt> = stack
                     .iter()
                     .map(|(_node, ints)| ints)
                     .chain(std::iter::once(&einsum.out_axes))
                     .flatten()
                     .copied()
                     .collect();
-                let inner_indices_set: HashSet<EinInt> = args_here
+                let inner_indices_set: HashSet<AxisInt> = args_here
                     .iter()
                     .flat_map(|(_node, ints)| ints)
                     .copied()
