@@ -43,7 +43,7 @@ pub fn maybe_distribute_uncached(
         if let Circuit::Add(_add) = &**operand && !_add.nodes.is_empty()&& ( operand.info().numel() >= BigUint::from(context.settings.distribute_min_size.unwrap_or(context.cache.max_single_tensor_numel)))
 
         {
-            let result = timed!(deep_canonicalize( compiler_simp(&distribute(node, i, true).unwrap().rc(),context),context),1,context.settings.verbose>=3);
+            let result = timed!(deep_canonicalize( compiler_simp(distribute(node, i, true).unwrap().rc(),context),context),1,context.settings.verbose>=3);
             context.cache.times_distributed+=1;
             return Some(result);
         }
@@ -55,18 +55,18 @@ pub fn maybe_distribute_uncached(
 #[pyo3(name = "deep_maybe_distribute")]
 pub fn deep_maybe_distribute_py(node: CircuitRc, settings: OptimizationSettings) -> CircuitRc {
     let context = &mut OptimizationContext::new_settings(settings);
-    deep_maybe_distribute(&node, context)
+    deep_maybe_distribute(node, context)
 }
 
-pub fn deep_maybe_distribute(node: &Circuit, context: &mut OptimizationContext) -> CircuitRc {
+pub fn deep_maybe_distribute(node: CircuitRc, context: &mut OptimizationContext) -> CircuitRc {
     deep_map_op_context(
-        node,
-        &|x: &Circuit, context: &mut OptimizationContext| match x {
+        node.clone(),
+        &|x: CircuitRc, context: &mut OptimizationContext| match &**x {
             Circuit::Einsum(ein) => maybe_distribute(ein, context),
             _ => None,
         },
         context,
         &mut HashMap::new(),
     )
-    .unwrap_or(node.clone().rc())
+    .unwrap_or(node)
 }
