@@ -11,10 +11,12 @@ pub fn strip_names_py(circuit: CircuitRc) -> CircuitRc {
 }
 pub fn strip_names(circuit: CircuitRc, context: &mut OptimizationContext) -> CircuitRc {
     deep_map_op_context(
-        &circuit,
-        &|circuit, _| match circuit {
+        circuit.clone(),
+        &|circuit, _| match &**circuit {
             Circuit::Symbol(_sym) => None,
-            _ => circuit.name().map(|_| circuit.clone().rename(None).rc()),
+            _ => circuit
+                .name()
+                .map(|_| (**circuit).clone().rename(None).rc()),
         },
         &mut (),
         &mut context.cache.stripped_names,
