@@ -11,6 +11,7 @@ use crate::util::{apply_fn_until_none, apply_fn_until_same, mapping_until_end, A
 use crate::{pyo3_prelude::*, timed, timed_value};
 use num_bigint::BigUint;
 
+use super::visit_circuit_unwrap;
 use super::{
     algebraic_rewrite::*,
     canonicalize::deep_canonicalize,
@@ -20,14 +21,14 @@ use super::{
         concat_drop_size_zero, concat_fuse, einsum_pull_concat, generalfunction_pull_concat,
         index_concat_drop_unreached,
     },
-    deep_map_unwrap, deep_map_unwrap_preorder,
+    deep_map_preorder_unwrap, deep_map_unwrap,
     diag_rewrite::{add_pull_diags, einsum_push_down_trace},
     prelude::*,
     scatter_rewrite::{
         add_pull_scatter, einsum_pull_scatter, index_einsum_to_scatter, scatter_elim_identity,
         scatter_fuse, scatter_pull_removable_axes,
     },
-    visit_circuit, Add, Concat, GeneralFunction, Index,
+    Add, Concat, GeneralFunction, Index,
 };
 
 /// seperate _py function because pyfunctions cant take reference arguments
@@ -236,7 +237,7 @@ pub fn compiler_simp_until_same(circ: CircuitRc) -> CircuitRc {
 
 #[pyfunction]
 pub fn deep_push_down_index(circ: CircuitRc, min_size: Option<usize>) -> CircuitRc {
-    deep_map_unwrap_preorder(circ, |circ| {
+    deep_map_preorder_unwrap(circ, |circ| {
         if min_size.is_none()
             || circ
                 .children()
@@ -263,7 +264,7 @@ pub fn deep_push_down_index(circ: CircuitRc, min_size: Option<usize>) -> Circuit
 pub fn deep_heuristic_nest_adds(circ: CircuitRc) -> CircuitRc {
     let circ = deep_canonicalize(circ, &mut Default::default());
     let mut seen_adds: HashSet<Add> = HashSet::new();
-    visit_circuit(circ.clone(), &mut |c: CircuitRc| {
+    visit_circuit_unwrap(circ.clone(), |c: CircuitRc| {
         if let Some(add) = c.as_add() {
             seen_adds.insert(add.clone());
         }
@@ -307,7 +308,7 @@ pub fn deep_heuristic_nest_adds(circ: CircuitRc) -> CircuitRc {
         mapping.insert(sup, new_sup.clone());
     }
 
-    deep_map_unwrap_preorder(circ, |c| {
+    deep_map_preorder_unwrap(circ, |c| {
         (**c).map_or_clone(|add: &Add| {
             let add = mapping_until_end(add, &mapping);
 
