@@ -8,7 +8,7 @@ use crate::{
     tensor_util::{TensorAxisIndex, TensorIndex},
     union_find::UnionFind,
     unwrap,
-    util::{is_unique, EinInt},
+    util::{is_unique, AxisInt},
 };
 
 use super::{
@@ -92,7 +92,7 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
                         let intersected_deduped: Vec<_> =
                             intersected_ints.iter().unique().collect();
                         if intersected_ints.len() != intersected_deduped.len() {
-                            let tuples_to_remove: HashSet<Box<[EinInt]>> =
+                            let tuples_to_remove: HashSet<Box<[AxisInt]>> =
                                 zip(intersected_ints.iter().enumerate(), &child.spec.output_ints)
                                     .filter_map(|((i, trace_int), oints)| {
                                         if intersected_ints
