@@ -6,7 +6,7 @@ use crate::pyo3_prelude::*;
 use crate::util::AxisInt;
 use crate::{
     cached_lambda,
-    py_types::{make_bytes_py, PyShape, Tensor},
+    py_types::{PyShape, Tensor},
     rearrange_spec::{OpSize, RearrangeSpec},
     tensor_util::{
         Shape, Slice, TensorAxisIndex, TensorIndex, TorchDeviceDtype, TorchDeviceDtypeOp,
@@ -25,8 +25,9 @@ pub use generalfunction_rewrite::{
 };
 pub use module_nodes::{ModuleNode, ModuleNodeArgSpec, ModuleNodeSpec};
 use num_bigint::BigUint;
-pub use parsing::parse_compiler_repr_bijection;
+pub use parsing::{parse_compiler_repr_bijection, parse_compiler_repr_bijection_py};
 use py_circuit_items::circuit_rust_to_py;
+use pyo3::types::PyBytes;
 use pyo3::{exceptions, pyclass::CompareOp};
 use std::collections::BTreeMap;
 use std::hash::Hash;
@@ -70,6 +71,7 @@ pub mod py_circuit_items;
 mod repr;
 pub mod sampling;
 pub mod scatter_rewrite;
+pub mod schedule_send;
 pub mod scheduled_execution;
 pub mod scheduling_z3;
 pub mod variable_nodes;
@@ -515,7 +517,9 @@ pub trait CircuitNodeDefer: CircuitNodeInit {
 }
 
 pub trait CircuitNodeUnion {
+    type TypeTag;
     fn variant_string(&self) -> String;
+    fn type_tag(&self) -> Self::TypeTag;
 }
 
 // not really needed to be so pedantic with ::std::...
@@ -579,6 +583,52 @@ macro_rules! define_circuit_union_impl {
             }
         }
 
+        paste::paste! {
+            #[derive(::std::fmt::Debug, ::std::clone::Clone, Copy, Eq, PartialEq, Hash)]
+            pub enum [<$name Type>] {
+                $(
+                    $x,
+                )*
+            }
+
+
+            impl<'source> $crate::pyo3::FromPyObject<'source> for [<$name Type>] {
+                fn extract(inp: &'source $crate::pyo3::PyAny) -> $crate::pyo3::PyResult<Self> {
+                    use $crate::pyo3::{type_object::PyTypeObject, types::PyType};
+
+                    let pairings: Vec<(Py<PyType>, [<$name Type>])> =
+                        Python::with_gil(|py| vec![
+                        $(
+                            ($x::type_object(py).into(), [<$name Type>]::$x),
+                        )*
+                        ]);
+
+                    for (t, out) in pairings {
+                        if t.is(inp) {
+                            return Ok(out);
+                        }
+                    }
+
+                    Err(PyErr::new::<exceptions::PyTypeError, _>(format!(
+                        "Expected one of the {} types",
+                        stringify!($name)
+                    )))
+                }
+            }
+
+            impl $crate::pyo3::IntoPy<$crate::pyo3::PyObject> for [<$name Type>] {
+                fn into_py(self, py: $crate::pyo3::Python<'_>) -> $crate::pyo3::PyObject {
+                    use crate::pyo3::{type_object::PyTypeObject};
+                    match self {
+                        $(
+                            Self::$x => $x::type_object(py).into(),
+                        )*
+                    }
+                }
+            }
+
+        }
+
 
         $crate::circuit_node_eq_ord!($name);
 
@@ -690,15 +740,26 @@ macro_rules! define_circuit_union_impl {
             }
         }
 
-        impl $crate::circuit::CircuitNodeUnion for $name {
-            fn variant_string(&self) -> String {
-                match self {
-                    $(
-                        Self::$x(_) => stringify!($x).to_owned(),
-                    )*
+        paste::paste! {
+            impl $crate::circuit::CircuitNodeUnion for $name {
+                type TypeTag = [<$name Type>];
+
+                fn variant_string(&self) -> String {
+                    match self {
+                        $(
+                            Self::$x(_) => stringify!($x).to_owned(),
+                        )*
+                    }
+                }
+
+                fn type_tag(&self) -> Self::TypeTag {
+                    match self {
+                        $(
+                            Self::$x(_) => Self::TypeTag::$x,
+                        )*
+                    }
                 }
             }
-
         }
 
         $(
@@ -749,6 +810,12 @@ define_circuit!(
     Cumulant,
 );
 
+#[pyfunction]
+pub fn print_circuit_type_check(x: CircuitType) -> CircuitType {
+    dbg!(x);
+    x
+}
+
 /// Define adhoc unions of different circuit types
 #[macro_export]
 macro_rules! define_circuit_union {
@@ -959,13 +1026,6 @@ impl<T: CircuitNodeDefer> CircuitNode for T {
 }
 
 pub type HashBytes = [u8; 32];
-#[derive(Clone, Copy, Hash, PartialEq, Eq)]
-pub struct PyHashBytes(pub [u8; 32]);
-impl IntoPy<PyObject> for PyHashBytes {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        make_bytes_py(py, &self.0).unwrap()
-    }
-}
 
 #[derive(Clone, Default)]
 pub struct CachedCircuitInfo {
@@ -1791,8 +1851,8 @@ impl PyCircuitBase {
     }
 
     #[getter]
-    fn hash(&self) -> PyHashBytes {
-        PyHashBytes(self.info().hash)
+    fn hash(&self) -> PyObject {
+        Python::with_gil(|py| PyBytes::new(py, &self.info().hash).into())
     }
 
     #[getter]
