@@ -6,7 +6,6 @@ use uuid::Uuid;
 
 use super::{
     module_nodes::{ModuleNodeArgSpec, ModuleNodeSpec},
-    print::rust_expression_notation_circuit,
     CircuitNode, OpSize, RearrangeSpec, TensorAxisIndex, TensorIndex,
 };
 use crate::{
@@ -234,30 +233,6 @@ impl TensorIndex {
     }
 }
 
-impl RustRepr for ModuleNodeSpec {
-    fn repr(&self) -> String {
-        format!(
-            "ModuleNodeSpec{{spec_circuit:{}, input_specs:{}, name:{}}}",
-            rust_expression_notation_circuit(self.spec_circuit.clone(), false),
-            self.input_specs.repr(),
-            repr_op_string(&self.name)
-        )
-    }
-}
-
-impl RustRepr for ModuleNodeArgSpec {
-    fn repr(&self) -> String {
-        format!(
-            "ModuleNodeArgSpec{{symbol:Symbol::new({},{},{}),batchable:{},expandable:{}}}",
-            self.symbol.info().shape.repr(),
-            self.symbol.uuid.repr(),
-            repr_op_string(&self.symbol.name_cloned()),
-            self.batchable,
-            self.expandable
-        )
-    }
-}
-
 #[allow(unused)]
 pub fn rustfmt_string(string: &str) -> String {
     // writing file bc dumb
