@@ -44,11 +44,13 @@ mod caching;
 pub mod circuit;
 pub mod hashmaps;
 pub mod lazy;
+mod lru_cache;
 pub mod opt_einsum;
 pub mod py_types;
 pub mod python_callables;
 pub mod rearrange_spec;
 pub mod rrfs;
+mod server;
 pub mod set_cover;
 pub mod smallvec;
 pub mod tensor_util;
@@ -132,6 +134,7 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
 
     m.add_class::<circuit::scheduled_execution::Schedule>()?;
     m.add_class::<circuit::scheduled_execution::ScheduleStats>()?;
+    m.add_class::<circuit::schedule_send::ScheduleToSend>()?;
 
     m.add_class::<circuit::module_nodes::ModuleNode>()?;
     m.add_class::<circuit::module_nodes::ModuleNodeSpec>()?;
@@ -142,6 +145,7 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_class::<circuit::StoredCumulantVar>()?;
     m.add_class::<circuit::Cumulant>()?;
     m.add_class::<circuit::circuit_matchers::Matcher>()?;
+    m.add_class::<lru_cache::TensorCacheRrfs>()?;
 
     m.add_function(wrap_pyfunction!(circuit::circuit_is_leaf, m)?)?;
     m.add_function(wrap_pyfunction!(circuit::circuit_is_irreducible_node, m)?)?;
@@ -312,6 +316,12 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
 
     // add more py function as desired or whatever...
 
-    m.add_function(wrap_pyfunction!(circuit::parse_compiler_repr_bijection, m)?)?;
+    m.add_function(wrap_pyfunction!(server::circuit_server_serve, m)?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::parse_compiler_repr_bijection_py,
+        m
+    )?)?;
+
+    m.add_function(wrap_pyfunction!(circuit::print_circuit_type_check, m)?)?;
     Ok(())
 }
