@@ -1,4 +1,4 @@
-use crate::circuit::{Einsum, EinsumAxes, Symbol};
+use crate::circuit::{CircuitConstructionError, Einsum, EinsumAxes, Symbol};
 use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 /// This file optimizes tensor contraction order, like Python's opt_einsum
 /// It specifies contraction order using rotating id's, like opt_einsum or numpy,
@@ -324,7 +324,16 @@ impl EinsumSpec {
             let output_ints = output
                 .chars()
                 .filter(|x| x != &' ')
-                .map(|x| ALPHABET_INV[&x.to_string()] as u8)
+                .map(|x| {
+                    ALPHABET_INV
+                        .get(&x.to_string())
+                        .cloned()
+                        .ok_or(CircuitConstructionError::EinsumStringInvalid {
+                            string: string.clone(),
+                            substring: x.to_string(),
+                        })
+                        .unwrap() as u8
+                })
                 .collect();
             let input_ints = inputs
                 .split(',')
@@ -332,7 +341,16 @@ impl EinsumSpec {
                     string
                         .chars()
                         .filter(|x| x != &' ')
-                        .map(|c| ALPHABET_INV[&c.to_string()] as u8)
+                        .map(|c| {
+                            ALPHABET_INV
+                                .get(&c.to_string())
+                                .cloned()
+                                .ok_or(CircuitConstructionError::EinsumStringInvalid {
+                                    string: string.to_owned(),
+                                    substring: c.to_string(),
+                                })
+                                .unwrap() as u8
+                        })
                         .collect()
                 })
                 .collect();
